@@ -2,7 +2,7 @@
 /*****************************************************************************
  * KWATCH --- KDE Log File Viewer
  *
- * $Id: klogwidget.h,v 0.10 2000/12/14 20:37:23 mj Exp $
+ * $Id: klogwidget.h,v 0.12 2001/01/18 21:57:30 mj Exp $
  *
  * QMultiLineEdit based widget for viewing log files
  *
@@ -42,7 +42,7 @@
 
 #include <qmultilineedit.h>
 #include <qtimer.h>
-#include <qpopmenu.h>
+#include <qpopupmenu.h>
 #include <qfile.h>
 
 #include "kwatchconf.h"
@@ -100,7 +100,8 @@ public:
 public:
     void addFile(const QString &);
     void updateConf();
-
+    void setPopupMenu(QPopupMenu *);
+    
 
 public slots:
     void reopen();
@@ -111,6 +112,8 @@ public slots:
 protected:
     void dropEvent(QDropEvent *);
     void dragEnterEvent(QDragEnterEvent *);
+    void mousePressEvent(QMouseEvent *);
+
 
 private:
     QString formatName(const QString &name);
@@ -121,6 +124,7 @@ private:
     kwatchConf       &m_cf;
 
     // member
+    QPopupMenu       *m_popup;
     QTimer           *m_timer;
     QList<KLogFile>  *m_files;
     KLogFile         *m_current;
