@@ -2,7 +2,7 @@
 /*****************************************************************************
  * KWATCH --- KDE Log File Viewer
  *
- * $Id: prefs.cpp,v 0.9 2000/12/14 20:37:23 mj Exp $
+ * $Id: prefs.cpp,v 0.10 2001/01/13 21:47:27 mj Exp $
  *
  * Class for kwatch preferences dialog
  *
@@ -190,14 +190,14 @@ kwatchPrefs::~kwatchPrefs() {
 
 void kwatchPrefs::changeParam1(int val)
 {
-    fprintf(stderr, "kwatchPrefs::changeParam1(%d)\n", val);
+//    fprintf(stderr, "kwatchPrefs::changeParam1(%d)\n", val);
 
     m_copy.maxlines = val;
 }
 
 void kwatchPrefs::changeParam2(int val)
 {
-    fprintf(stderr, "kwatchPrefs::changeParam2(%d)\n", val);
+//    fprintf(stderr, "kwatchPrefs::changeParam2(%d)\n", val);
 
     m_copy.bufsize = val;
 }
@@ -231,8 +231,8 @@ void kwatchPrefs::addFile()
 {
     QString s = KFileDialog::getOpenFileName(m_copy.logdir, QString::null,
 					     this, i18n("Add Log File")   );
-    fprintf(stderr, "kwatchPrefs::addFile() s=%s\n",
-	    (const char *)s);
+//    fprintf(stderr, "kwatchPrefs::addFile() s=%s\n",
+//	    (const char *)s);
 
     if(!s.isNull() && !s.isEmpty()) 
     {
